#!/usr/bin/env python

import micropython.cmd
from micropython.graph import get_graph
import rsvp
import sys
import os

def show_code(code):
    for i, x in enumerate(code):
        print i, x

def show_table_usage(raw_table, slice_size=100):
    for x in xrange(0, len(raw_table), slice_size):
        table_slice = raw_table[x:x+slice_size]
        print "%6d" % (len(table_slice) - table_slice.count(None)), \
            "".join(entry and "#" or "_" for entry in table_slice)

def attrs(obj):
    for name, attr in obj.items():
        print name, attr

# Main program.

if __name__ == "__main__":
    args = sys.argv[2:]
    path = sys.path[:]

    if "--help" in sys.argv:
        print "Optimisations:"
        print micropython.cmd.show_optimisations()
        sys.exit(1)

    if len(sys.argv) > 1:
        filename = os.path.abspath(sys.argv[1])
        path.append(os.path.split(filename)[0])
    else:
        filename = None

    # Load the program.

    try:
        p = micropython.cmd.get_program(filename, path, args)
        if filename is None:
            print "Loading module micropython ..."
            m = p.get_importer().load("micropython")
        else:
            m = p.get_importer().get_module("__main__")

        # Build the program.

        if "-m" in args or "-t" in args:
            rm = rsvp.machine(p, debug=("-g" in args), abort_upon_exception=("-x" in args))
            if "-t" in args:
                success = rm.test(m)
                print "Test successful?", success

        ot = p.get_object_table()
        pt = p.get_parameter_table()

    # Report any errors.

    except micropython.ProcessingError, exc:
        print repr(exc)
        if "-tb" in args:
            raise

# vim: tabstop=4 expandtab shiftwidth=4
